/*------------------------------------------------------------------------------
 * MDK Middleware - Component ::USB:Device
 * Copyright (c) 2004-2014 ARM Germany GmbH. All rights reserved.
 *------------------------------------------------------------------------------
 * Name:    VirtualCOM.c
 * Purpose: USB Device virtual COM port demonstration
 *----------------------------------------------------------------------------*/

#include "cmsis_os.h"
#include "rl_usb.h"

#include "Board_GLCD.h"
#include "GLCD_Config.h"

#include "Driver_USART.h"

#include "stm32f2xx_hal.h"

extern GLCD_FONT GLCD_Font_6x8;
extern GLCD_FONT GLCD_Font_16x24;

extern ARM_DRIVER_USART Driver_USART1;
extern ARM_DRIVER_USART Driver_USART3;

#define BUF_SZ 128

// UART -> USB
uint8_t  uart2usb_buf[BUF_SZ];
volatile uint32_t uart2usb_in;
volatile uint32_t uart2usb_out;

// USB -> UART
uint8_t  usb2uart_buf[BUF_SZ];
volatile bool uart_send_busy;

         bool bridge_ready = false;
volatile bool uart_setup   = false;

uint8_t usb_device;
ARM_DRIVER_USART *pUSART;

extern uint32_t os_time;

uint32_t HAL_GetTick(void) {
  return os_time;
}

/* System Clock Configuration */
void SystemClock_Config(void) {
  RCC_OscInitTypeDef RCC_OscInitStruct;
  RCC_ClkInitTypeDef RCC_ClkInitStruct;

  /* Enable HSE Oscillator and activate PLL with HSE as source */
  RCC_OscInitStruct.OscillatorType = RCC_OSCILLATORTYPE_HSE;
  RCC_OscInitStruct.HSEState = RCC_HSE_ON;
  RCC_OscInitStruct.PLL.PLLState = RCC_PLL_ON;
  RCC_OscInitStruct.PLL.PLLSource = RCC_PLLSOURCE_HSE;
  RCC_OscInitStruct.PLL.PLLM = 25;
  RCC_OscInitStruct.PLL.PLLN = 240;
  RCC_OscInitStruct.PLL.PLLP = RCC_PLLP_DIV2;
  RCC_OscInitStruct.PLL.PLLQ = 5;
  HAL_RCC_OscConfig(&RCC_OscInitStruct);

  /* Select PLL as system clock source and configure the HCLK, PCLK1 and PCLK2
     clocks dividers */
  RCC_ClkInitStruct.ClockType = RCC_CLOCKTYPE_SYSCLK | RCC_CLOCKTYPE_HCLK |
                                RCC_CLOCKTYPE_PCLK1  | RCC_CLOCKTYPE_PCLK2;
  RCC_ClkInitStruct.SYSCLKSource = RCC_SYSCLKSOURCE_PLLCLK;
  RCC_ClkInitStruct.AHBCLKDivider = RCC_SYSCLK_DIV1;
  RCC_ClkInitStruct.APB1CLKDivider = RCC_HCLK_DIV4;
  RCC_ClkInitStruct.APB2CLKDivider = RCC_HCLK_DIV2;
  HAL_RCC_ClockConfig(&RCC_ClkInitStruct, FLASH_LATENCY_3);
}

void USART_Callback (uint32_t event) {

  if (event & ARM_USART_EVENT_SEND_COMPLETE) {
    uart_send_busy = false;
  }
  if (event & ARM_USART_EVENT_RECEIVE_COMPLETE) {
    uart2usb_in += BUF_SZ;
    pUSART->Receive(uart2usb_buf, BUF_SZ);
  }
}

int main (void) {
  volatile uint32_t cnt;
  int32_t  ret_val;

  HAL_Init();
  SystemClock_Config();

  GLCD_Initialize         ();
  GLCD_SetBackgroundColor (GLCD_COLOR_BLUE);
  GLCD_SetForegroundColor (GLCD_COLOR_WHITE);
  GLCD_ClearScreen        ();
  GLCD_SetFont            (&GLCD_Font_16x24);
  GLCD_DrawString         (0, 0*24, "    USB Device      ");
  GLCD_DrawString         (0, 1*24, "    CDC Class       ");
  GLCD_DrawString         (0, 2*24, " VirtualCOM Example ");
  GLCD_DrawString         (0, 4*24, " USBFS: VCOMx       ");
  GLCD_DrawString         (0, 5*24, " USBHS: VCOMx       ");
  GLCD_DrawString         (0, 8*24, "  Keil Tools by ARM ");
  GLCD_DrawString         (0, 9*24, "    www.keil.com    ");

  USBD_Initialize    (0);               // USB Device 0 Initialization
  USBD_Connect       (0);               // USB Device 0 Connect

  USBD_Initialize    (1);               // USB Device 1 Initialization
  USBD_Connect       (1);               // USB Device 1 Connect

  // Wait until first USB Device is configured
  while (USBD_Configured (usb_device ^= 1) == 0);
  pUSART = (usb_device == 1) ? &Driver_USART3 : &Driver_USART1;

  while (1) {
    if (USBD_Configured (usb_device)) {
      if (uart_setup) {
        bridge_ready   = true;
        uart_setup     = false;
        uart_send_busy = false;
        uart2usb_in  = 0;
        uart2usb_out = 0;
        pUSART->Receive(uart2usb_buf, BUF_SZ);
      }
      if (bridge_ready) {

        // UART -> USB
        cnt  = uart2usb_in;
        cnt += pUSART->GetRxCount();
        if (uart2usb_out < cnt) {
          cnt -= uart2usb_out;
          ret_val = USBD_CDC_ACM_WriteData (usb_device, (const uint8_t *) (uart2usb_buf + (uart2usb_out & (BUF_SZ - 1))), cnt);
          if (ret_val > 0) uart2usb_out += ret_val;
        }

        // USB -> UART
        if (uart_send_busy == false) {
          cnt = USBD_CDC_ACM_ReadData(usb_device, usb2uart_buf, BUF_SZ);
          if (cnt > 0) {
            uart_send_busy = true;
            pUSART->Send(usb2uart_buf, cnt);
          }
        }
      }
    }
  }
}
